==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/FunctionFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { FunctionFilterExpressionDescription } from "./FunctionFilterExpressionDescription";
/**
 * @hidden
 */
export let FunctionFilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunctionFilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (FunctionFilterExpressionDescriptionMetadata.a == null) {
                FunctionFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunctionFilterExpressionDescriptionMetadata.c(FunctionFilterExpressionDescriptionMetadata.a);
            }
            if (a.k(FunctionFilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(FunctionFilterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("FunctionType", "ExportedType:string:FilterExpressionFunctionType");
            a.item("FunctionType@names", "Contains;EndsWith;StartsWith;Length;IndexOf;Replace;Substring;ToLower;ToUpper;Trim;Concat;Day;Hour;Minute;Month;Second;Year;Round;Floor;Ceiling;Date;Time;Now;IsOf;Cast");
            a.item("FunctionArguments", "Collection:FilterExpression:FilterExpressionCollection:FilterExpression");
        }
        static d(a) {
            FunctionFilterExpressionDescriptionMetadata.b(a);
            a.ad("FunctionFilterExpression", () => new FunctionFilterExpressionDescription());
            a.ac("FunctionFilterExpression", FunctionFilterExpressionDescriptionMetadata.a);
        }
    }
    FunctionFilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(FunctionFilterExpressionDescriptionMetadata, 'FunctionFilterExpressionDescriptionMetadata');
    FunctionFilterExpressionDescriptionMetadata.a = null;
    return FunctionFilterExpressionDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/FunctionFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { FunctionFilterExpressionDescription } from "./FunctionFilterExpressionDescription";
/**
 * @hidden
 */
export let FunctionFilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunctionFilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (FunctionFilterExpressionDescriptionMetadata.a == null) {
                FunctionFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunctionFilterExpressionDescriptionMetadata.c(FunctionFilterExpressionDescriptionMetadata.a);
            }
            if (a.k(FunctionFilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(FunctionFilterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("FunctionType", "ExportedType:string:FilterExpressionFunctionType");
            a.item("FunctionType@names", "Contains;EndsWith;StartsWith;Length;IndexOf;Replace;Substring;ToLower;ToUpper;Trim;Concat;Day;Hour;Minute;Month;Second;Year;Round;Floor;Ceiling;Date;Time;Now;IsOf;Cast;Env");
            a.item("FunctionArguments", "Collection:FilterExpression:FilterExpressionCollection:FilterExpression");
        }
        static d(a) {
            FunctionFilterExpressionDescriptionMetadata.b(a);
            a.ae("FunctionFilterExpression", () => new FunctionFilterExpressionDescription());
            a.ad("FunctionFilterExpression", FunctionFilterExpressionDescriptionMetadata.a);
        }
    }
    FunctionFilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(FunctionFilterExpressionDescriptionMetadata, 'FunctionFilterExpressionDescriptionMetadata');
    FunctionFilterExpressionDescriptionMetadata.a = null;
    return FunctionFilterExpressionDescriptionMetadata;
})();
